AmericanPut

Struct AmericanPut 

pub struct AmericanPut {
    pub risk_free_rate: f64,
    pub volatility: f64,
    pub strike: f64,
    pub dx: f64,
}
American Put Option

Models the optimal exercise strategy for an American Put option. This is formulated as an optimal stopping problem, but can be solved via HJB by treating the exercise decision as a control.

Dynamics follow Geometric Brownian Motion for the underlying asset.

Fields

risk_free_rate: f64

Risk-free interest rate (r).

volatility: f64

Volatility of the underlying asset ($\sigma$).

strike: f64

Strike price (K).

dx: f64

Spatial discretization step size (dx) used for finite difference coefficients.

Implementations

Source

impl AmericanPut

pub fn new(risk_free_rate: f64, volatility: f64, strike: f64, dx: f64) -> Self

Creates an American put model.

Examples
use solver::models::american_put::AmericanPut;
let put = AmericanPut::new(0.05, 0.2, 100.0, 1.0);
assert_eq!(put.strike, 100.0);
pub fn set_dx(&mut self, dx: f64)

Updates the spatial step size used by the finite-difference transport coefficients.

Examples
use solver::models::american_put::AmericanPut;
let mut put = AmericanPut::new(0.05, 0.2, 100.0, 1.0);
put.set_dx(0.5);
assert_eq!(put.dx, 0.5);