pub struct AmericanPut {
pub risk_free_rate: f64,
pub volatility: f64,
pub strike: f64,
pub dx: f64,
}Expand description
American Put Option
Models the optimal exercise strategy for an American Put option. This is formulated as an optimal stopping problem, but can be solved via HJB by treating the exercise decision as a control.
Dynamics follow Geometric Brownian Motion for the underlying asset.
Fields
risk_free_rate: f64Risk-free interest rate (r).
volatility: f64Volatility of the underlying asset ($\sigma$).
strike: f64Strike price (K).
dx: f64Spatial discretization step size (dx) used for finite difference coefficients.
Implementations